<?php

function squarepress_dequeue_script() {
    wp_dequeue_style('square-fonts');
    wp_dequeue_script('square-custom');
}

add_action('wp_print_scripts', 'squarepress_dequeue_script', 100);

add_action('wp_enqueue_scripts', 'squarepress_enqueue_scripts');

function squarepress_enqueue_scripts() {
    wp_enqueue_style('squarepress-parent-style', get_template_directory_uri() . '/style.css');
    wp_enqueue_style('squarepress-style', get_stylesheet_directory_uri() . '/style.css', array('squarepress-parent-style'), '1.0');
    wp_add_inline_style('squarepress-style', squarepress_dymanic_styles());
    wp_enqueue_script('squarepress-custom', get_stylesheet_directory_uri() . '/js/squarepress-custom.js', array('jquery'), '1.0', true);
    wp_enqueue_style('squarepress-fonts', squarepress_fonts_url(), array(), null);
}


function squarepress_fonts_url() {
    $fonts_url = '';
    $fonts = array();
    $subsets = 'latin,latin-ext';

    /*
     * Translators: If there are characters in your language that are not supported
     * by Open Sans, translate this to 'off'. Do not translate into your own language.
     */
    if ('off' !== _x('on', 'Poppins font: on or off', 'squarepress')) {
        $fonts[] = 'Poppins:300,300i,400,400i,500,700,700i';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Inconsolata, translate this to 'off'. Do not translate into your own language.
     */
    if ('off' !== _x('on', 'Karla font: on or off', 'squarepress')) {
        $fonts[] = 'Karla';
    }

    /*
     * Translators: To add an additional character subset specific to your language,
     * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
     */
    $subset = _x('no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'squarepress');

    if ('cyrillic' == $subset) {
        $subsets .= ',cyrillic,cyrillic-ext';
    } elseif ('greek' == $subset) {
        $subsets .= ',greek,greek-ext';
    } elseif ('devanagari' == $subset) {
        $subsets .= ',devanagari';
    } elseif ('vietnamese' == $subset) {
        $subsets .= ',vietnamese';
    }

    if ($fonts) {
        $fonts_url = add_query_arg(array(
            'family' => urlencode(implode('|', $fonts)),
            'subset' => urlencode($subsets),
                ), '//fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

function squarepress_dymanic_styles() {
    $color = get_theme_mod('square_template_color', '#5BC2CE');
    $squarepress_tab_bg = get_theme_mod('squarepress_tab_bg', get_stylesheet_directory_uri(). '/images/banner-image.jpg');
    $squarepress_testimonial_bg = get_theme_mod('squarepress_testimonial_bg', get_stylesheet_directory_uri(). '/images/banner-image.jpg');

    $custom_css = "
        body .sq-top-header,
        body .sq-tab li.sq-active,
        body .bx-wrapper .bx-pager.bx-default-pager a, 
        body .bx-wrapper .bx-pager.bx-default-pager a.active,
        body .bx-wrapper .bx-pager.bx-default-pager a:hover,
        body .sq-featured-post.theme-colored-box{background:" . sanitize_hex_color($color) . "}

        
        #sq-tab-section{background-image: url(". esc_url($squarepress_tab_bg) .")}
        #sq-testimonial-section{background-image: url(". esc_url($squarepress_testimonial_bg) .")}

        @media screen and (max-width: 900px){
            #sq-site-navigation{border-color:" . sanitize_hex_color($color) . "}
        }
    ";

    return squarepress_css_strip_whitespace($custom_css);
}

function squarepress_css_strip_whitespace($css) {
    $replace = array(
        "#/\*.*?\*/#s" => "", // Strip C style comments.
        "#\s\s+#" => " ", // Strip excess whitespace.
    );
    $search = array_keys($replace);
    $css = preg_replace($search, $replace, $css);

    $replace = array(
        ": " => ":",
        "; " => ";",
        " {" => "{",
        " }" => "}",
        ", " => ",",
        "{ " => "{",
        ";}" => "}", // Strip optional semicolons.
        ",\n" => ",", // Don't wrap multiple selectors.
        "\n}" => "}", // Don't wrap closing braces.
        "} " => "}\n", // Put each rule on it's own line.
    );
    $search = array_keys($replace);
    $css = str_replace($search, $replace, $css);

    return trim($css);
}

add_filter('pt-ocdi/import_files', 'squarepress_demo_import_files', 100);

function squarepress_demo_import_files($array) {
    return array(
        array(
            'import_file_name' => 'SquareOne Demo Import',
            'local_import_file' => trailingslashit(get_stylesheet_directory()) . 'demo-data/squarepress-content.xml',
            'local_import_widget_file' => trailingslashit(get_stylesheet_directory()) . 'demo-data/squarepress-widgets.wie',
            'local_import_customizer_file' => trailingslashit(get_stylesheet_directory()) . 'demo-data/squarepress-customizer.dat',
            'import_preview_image_url' => 'https://i0.wp.com/themes.svn.wordpress.org/squarepress/1.0.0/screenshot.png',
            'preview_url' => 'https://demo.hashthemes.com/squarepress'
        )
    );
}

add_action( 'wp_head', 'squarepress_remove_actions', 10 );

function squarepress_remove_actions(){
    remove_action('pt-ocdi/after_import', 'square_after_import_setup');
}

add_action('pt-ocdi/after_import', 'squarepress_after_import_setup', 30);

function squarepress_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by('name', 'Primary Menu', 'nav_menu');

    set_theme_mod('nav_menu_locations', array(
        'primary' => $main_menu->term_id,
            )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title('Home Page');
    $blog_page_id = get_page_by_title('Blog');

    update_option('show_on_front', 'page');
    update_option('page_on_front', $front_page_id->ID);
    update_option('page_for_posts', $blog_page_id->ID);
}

/**
 * Customizer additions.
 */
require get_stylesheet_directory() . '/inc/customizer.php';
